@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::SHLOMIF;
-$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000005';
+$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000006';
 our $AUTHORITY = 'cpan:SHLOMIF';
 
 use 5.014;
@@ -301,7 +301,7 @@ Dist::Zilla::PluginBundle::SHLOMIF - Dist::Zilla plugins for me
 
 =head1 VERSION
 
-version 0.000005
+version 0.000006
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,7 @@ equivalent to (FILL IN/update).
 
     [PkgVersion]
     [Authority]
-    authority = cpan:DOY
+    authority = cpan:SHLOMIF
 
     [PodCoverageTests]
     [PodSyntaxTests]
@@ -390,7 +390,7 @@ Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Jesse Luehrs.
+This software is Copyright (c) 2017 by Jesse Luehrs.
 
 This is free software, licensed under:
 
